package com.book.push.controller;

import com.book.push.dao.pojo.User;
import com.book.push.service.dao.UserService;
import lombok.AllArgsConstructor;
import me.chanjar.weixin.common.bean.WxOAuth2UserInfo;
import me.chanjar.weixin.common.bean.oauth2.WxOAuth2AccessToken;
import me.chanjar.weixin.common.error.WxErrorException;
import me.chanjar.weixin.mp.api.WxMpService;
import org.checkerframework.checker.units.qual.A;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;

/**
 * 接收微信重定向
 * @author win7
 */
@AllArgsConstructor
@Controller
@RequestMapping("/wx/redirect/{appid}")
public class WxRedirectController {
    private final WxMpService wxService;
    @Autowired
    private UserService userService;
    /**
     * //FIXME
     * 前端页面url
     */
    private final static String FRONT_URL = "/%s/%s/%d";

    /**
     * 接收微信静默授权，获取用户信息，跳转前台页面
     *
     * @param appid
     * @param code
     * @param map
     * @return
     */
    @RequestMapping("/greet")
    public String greetUser(@PathVariable String appid, @RequestParam String code, @RequestParam String state, ModelMap map) {
        if (!this.wxService.switchover(appid)) {
            throw new IllegalArgumentException(String.format("未找到对应appid=[%s]的配置，请核实！", appid));
        }

        try {
            WxOAuth2AccessToken accessToken = wxService.getOAuth2Service().getAccessToken(code);
            WxOAuth2UserInfo wxOAuth2UserInfo = wxService.getOAuth2Service().getUserInfo(accessToken, null);
            map.put("user", wxOAuth2UserInfo);
            User user = new User();
            user.setOpenid(wxOAuth2UserInfo.getOpenid());
            user = userService.selectUserByUser(user);
            if (user==null){
                //todo
            }
            String openid = user.getOpenid();
            String frontUrl = String.format(FRONT_URL, state, appid, user.getId());
            return "redirect:" + frontUrl;
        } catch (WxErrorException e) {
            e.printStackTrace();
        }

        return "greet_user";
    }
}
